clear
set more off

*******************************************
*
* This .do file creates the analysis reported in "The Big Five Personality Traits in the Political Arena"
* Annual Review of Political Science
* Alan Gerber, Gregory Huber, David Doherty, Conor Dowling
*
* This version: January 26, 2012
*
*******************************************

local localpath=""

set mem 500m
use "`localpath'sourcedata\ccap_validated.dta", clear

*******************************************
*
* BIG FIVE ITEMS/TIPI 
*
*******************************************
*All are 7 point scales, missing/skipped set to missing
recode profile40 profile41 profile42 profile43 profile44 profile45 profile46 profile47 profile48 profile49 (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (7=7) (*=.), gen(b_p_extraverted b_p_critical b_p_dependable b_p_anxious b_p_open b_p_reserved b_p_sympathetic b_p_disorganized b_p_calm b_p_conventional)

*generate reversed values of items that need to be reverse scored;
recode b_p_disorganized b_p_conventional b_p_critical b_p_anxious b_p_reserved (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7) (*=.), gen(b_p_disorganized_R b_p_conventional_R b_p_critical_R b_p_anxious_R b_p_reserved_R)

*Items range from 0 to 1 -- higher values indicate more of the trait
*Big Five - conscientiousness
gen BF_conscientiousness = (((b_p_dependable + b_p_disorganized_R)/2)-1)/6 

*Big Five - openness to experiences
gen BF_openness = (((b_p_open + b_p_conventional_R)/2)-1)/6

*Big Five - agreeableness
gen BF_agreeableness = (((b_p_sympathetic + b_p_critical_R)/2)-1)/6

*Big Five - emotional stability
gen BF_stability = (((b_p_calm + b_p_anxious_R)/2)-1)/6

*Big Five - extraversion
gen BF_extraversion = (((b_p_extraverted + b_p_reserved_R)/2)-1)/6

forvalues i=161/204{
local item=`i'-160
gen bfi`item'=post_yal`i'
local ilabel : variable label post_yal`i'
label var bfi`item' "BFI Item `item': `ilabel'"
}

*******************************************
*
* BIG FIVE ITEMS/BFI
*
*******************************************
*Reverse code as necessary
recode bfi* (8 9=.)
recode bfi6 bfi21 bfi31 bfi2 bfi12 bfi27 bfi37 bfi8 bfi18 bfi23 bfi43 bfi9 bfi24 bfi34 bfi35 bfi41 (5=1) (4=2) (3=3) (2=4) (1=5)

egen BFI_extraversion=rowmean(bfi1 bfi6 bfi11 bfi16 bfi21 bfi26 bfi31 bfi36)
replace BFI_extraversion=(BFI_extraversion-1)/4
egen MISS_extraversion=rowmiss(bfi1 bfi6 bfi11 bfi16 bfi21 bfi26 bfi31 bfi36)
replace BFI_extraversion=. if MISS_extraversion>0

egen BFI_agreeable=rowmean(bfi2 bfi7 bfi12 bfi17 bfi22 bfi27 bfi32 bfi37 bfi42)
replace BFI_agreeable=(BFI_agreeable-1)/4
egen MISS_agreeable=rowmiss(bfi2 bfi7 bfi12 bfi17 bfi22 bfi27 bfi32 bfi37 bfi42)
replace BFI_agreeable=. if MISS_agreeable>0

egen BFI_conscientious=rowmean(bfi3 bfi8 bfi13 bfi18 bfi23 bfi28 bfi33 bfi38 bfi43)
replace BFI_conscientious=(BFI_conscientious-1)/4
egen MISS_conscientious=rowmiss (bfi3 bfi8 bfi13 bfi18 bfi23 bfi28 bfi33 bfi38 bfi43)
replace BFI_conscientious=. if MISS_conscientious>0

egen BFI_stability=rowmean(bfi4 bfi9 bfi14 bfi19 bfi24 bfi29 bfi34 bfi39)
replace BFI_stability=abs(BFI_stability-5)/4
egen MISS_stability=rowmiss(bfi4 bfi9 bfi14 bfi19 bfi24 bfi29 bfi34 bfi39)
replace BFI_stability=. if MISS_stability>0

egen BFI_openness=rowmean(bfi5 bfi10 bfi15 bfi20 bfi25 bfi30 bfi35 bfi40 bfi41 bfi44)
replace BFI_openness=(BFI_openness-1)/4
egen MISS_openness=rowmiss(bfi5 bfi10 bfi15 bfi20 bfi25 bfi30 bfi35 bfi40 bfi41 bfi44)
replace BFI_openness=. if MISS_openness>0

*******************************************
*
* BIG FIVE ITEMS/BFI FACET MEASURES
*
*******************************************
egen FACET_assertiveness=rowmean(bfi1 bfi6 bfi21 bfi26 bfi31)
replace FACET_assertiveness=(FACET_assertiveness-1)/4
egen MISS_assertiveness=rowmiss(bfi1 bfi6 bfi21 bfi26 bfi31)
replace FACET_assertiveness=. if MISS_assertiveness>0

egen FACET_activity=rowmean(bfi11 bfi16)
replace FACET_activity=(FACET_activity-1)/4
egen MISS_activity=rowmiss(bfi11 bfi16)
replace FACET_activity=. if MISS_activity>0

egen FACET_altruism=rowmean(bfi7 bfi22 bfi27 bfi32)
replace FACET_altruism=(FACET_altruism-1)/4
egen MISS_altruism=rowmiss(bfi7 bfi22 bfi27 bfi32)
replace FACET_altruism=. if MISS_altruism>0

egen FACET_compliance=rowmean(bfi2 bfi12 bfi17)
replace FACET_compliance=(FACET_compliance-1)/4
egen MISS_compliance=rowmiss(bfi2 bfi12 bfi17)
replace FACET_compliance=. if MISS_compliance>0

egen FACET_order=rowmean(bfi8 bfi18)
replace FACET_order=(FACET_order-1)/4
egen MISS_order=rowmiss(bfi8 bfi18)
replace FACET_order=. if MISS_order>0

egen FACET_selfdiscipline=rowmean(bfi13 bfi23 bfi28 bfi38 bfi43)
replace FACET_selfdiscipline=(FACET_selfdiscipline-1)/4
egen MISS_selfdiscipline=rowmiss(bfi13 bfi23 bfi28 bfi38 bfi43)
replace FACET_selfdiscipline=. if MISS_selfdiscipline>0

egen FACET_anxiety=rowmean(bfi9 bfi19 bfi34 bfi39)
replace FACET_anxiety=(FACET_anxiety-1)/4
egen MISS_anxiety=rowmiss(bfi9 bfi19 bfi34 bfi39)
replace FACET_anxiety=. if MISS_anxiety>0

egen FACET_depression=rowmean(bfi4 bfi29)
replace FACET_depression=(FACET_depression-1)/4
egen MISS_depression=rowmiss(bfi4 bfi29)
replace FACET_depression=. if MISS_depression>0

egen FACET_aesthetics=rowmean(bfi30 bfi41 bfi44)
replace FACET_aesthetics=(FACET_aesthetics-1)/4
egen MISS_aesthetics=rowmiss(bfi30 bfi41 bfi44)
replace FACET_aesthetics=. if MISS_aesthetics>0

egen FACET_ideas=rowmean(bfi10 bfi15 bfi25 bfi35 bfi40)
replace FACET_ideas=(FACET_ideas-1)/4
egen MISS_ideas=rowmiss(bfi10 bfi15 bfi25 bfi35 bfi40)
replace FACET_ideas=. if MISS_ideas>0

foreach i of varlist BFI_* BF_* FACET_* {
egen std_`i'=std(`i')
replace `i'=std_`i'
}

*FLIP EMOTIONAL STABILITY -> NEUROTICISM 
gen BFI_neurotic=BFI_stability*-1
gen BF_neurotic=BF_stability*-1

label var BFI_extraversion "Extraversion Domain (M=0, SD=1)"
label var BFI_agreeable "Agreeableness Domain (M=0, SD=1)"
label var BFI_conscientious "Conscientiousness Domain (M=0, SD=1)"
label var BFI_stability "Emotional Stability Domain (M=0, SD=1)"
label var BFI_neurotic "Neuroticism Domain (M=0, SD=1)"
label var BFI_openness "Openness Domain (M=0, SD=1)"

label var BF_extraversion "Extraversion Domain (M=0, SD=1)"
label var BF_agreeable "Agreeableness Domain (M=0, SD=1)"
label var BF_conscientious "Conscientiousness Domain (M=0, SD=1)"
label var BF_stability "Emotional Stability Domain (M=0, SD=1)"
label var BF_neurotic "Neuroticism Domain (M=0, SD=1)"
label var BF_openness "Openness Domain (M=0, SD=1)"

rename BFI_stability R_BFI_stability
rename BF_stability R_BF_stability

label var FACET_assertiveness "Facet: Assertiveness (Extraversion)"
label var FACET_activity "Facet: Activity (Extraversion)"
label var FACET_altruism "Facet: Altruism (Agreeableness)"
label var FACET_compliance "Facet: Compliance (Agreeableness)"
label var FACET_order "Facet: Order (Conscientiousness)"
label var FACET_selfdiscipline "Facet: Self-Discipline (Conscientiousness)"
label var FACET_anxiety "Facet: Anxiety (Neuroticism)"
label var FACET_depression "Facet: Depression (Neuroticism)"
label var FACET_aesthetics "Facet: Aesthetics (Openness)"
label var FACET_ideas "Facet: Ideas (Openness)"

drop MISS_* std_*

*******************************************
*
* RECODE ALL OTHER VARIABLES
*
*******************************************

***DEMOGRAPHIC VARIABLES

* State, drop if missing state
drop if profile66==0 | profile66==.
quietly tab profile66, gen(stateC_)
* drop State5 indicator--California (dominant category when weighted)
drop stateC_5

* Gender, drop if missing
recode profile54 (1=0) (2=1) (*=.), gen(female)
drop if female==.
label var female "Female = 1"

* Race, no missing
recode profile55 (1=1) (2/8=0) (*=.), gen(r_white)
drop if r_white==.
recode profile55 (1=0) (2=1) (3/8=0) (*=.), gen(r_black)
recode profile55 (1/2=0) (3=1) (4/8=0) (*=.), gen(r_hispanic)
recode profile55 (1/3=0) (4/8=1) (*=.), gen(r_other)
label var r_white "White = 1"
label var r_black "Black = 1"
label var r_hispanic "Hispanic = 1"
label var r_other "Other (Native American,Asian,Mixed,Other) = 1"

* Education, drop missing
recode profile57 (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (*=.), gen(educ)
drop if educ==.
label var educ "Education (1=No HS; 6=Post-grad)"
tab educ, gen(educC_)
*drop category 3
drop educC_3
label var educC_1 "Educ<HS"
label var educC_2 "Educ=HS"
label var educC_4 "Educ=2 year college"
label var educC_5 "Educ=College"
label var educC_6 "Educ=Post Grad"

* Family Income
* Skipped/RF set to 15, plus indicator for missing
* Not asked is dropped/missing
recode profile59 (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (7=7) (8=8) (9=9) (10=10) (11=11) (12=12) (13=13) (14=14) (15=15) (98=15), gen(income)

drop if income==.
gen incomemis = (income==15)
label var incomemis "Income Refused"
label var income "Income (1=<10k; 14=>150k; 15=RF)"

* Age
* No missing values
gen birthyr=profile51
label var birthyr "birth year"
gen age=2008-birthyr 
label var age "Age (Years)"
gen age2=(age^2)/100
label var age2 "Age^2/100"

***OUTCOME VARIABLES

* Ideology
* Skipped/Not asked/Missing=Missing. Not sure=Moderate
recode bcap700s (1=2) (2=1) (3=0) (4=-1) (5=-2) (6=0) (*=.), gen(b_ideol_withns)
label var b_ideol_withns "Self-Reported Ideology (-2=Very Cons.;2=Very Lib., NotSure=0)"

* This is an alternative measure in which not sure is set to missing
* recode bcap700s (1=2) (2=1) (3=0) (4=-1) (5=-2) (*=.), gen(b_ideol)
* label var b_ideol "Self-Reported Ideology (-2=Very Cons.;2=Very Lib., NotSure+=Miss.)"

* Economic policy opinions
recode bcap20 (1=1) (2=2) (3=3) (*=.), gen(healthcare)
replace healthcare=(healthcare-1)/2
label var healthcare "Individualist Health Care (0-1)"

recode bcap24 (1=1) (2=2) (3=3) (4=4) (*=.), gen(taxes)
replace taxes=(taxes-1)/3
label var taxes "Oppose Taxing the Rich (0-1)"

* Social policy opinions
recode profile15 (1=1) (2=2) (3=3) (4=4) (*=.), gen(abortion)
replace abortion=(abortion-1)/3
label var abortion "Against Abortion (0-1)"

recode profile19 (1=1) (2=2) (3=3) (4=4) (*=.), gen(civilunion)
replace civilunion=(civilunion-1)/3
label var civilunion "Oppose Civil Unions (0-1)"

recode pcap600 (1 2 3=1) (4=0) (*=.), gen(repvote)
label var repvote "Report Voting (1=yes)"

recode bcap813 (1=1) (2=.5) (3=0) (*=.), gen(interest)
egen std_interest=std(interest)
replace interest=std_interest
label var interest "Political Interest (M=0, SD=1)"

*******************************************
*
* SET CONSTANT SAMPLE
*
*******************************************
reg b_ideol repvote interest healthcare taxes abortion civilunion BF_* BFI_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [pweight=psweight], r
gen insample=e(sample)
drop if insample==0

*******************************************
*
* GENERATE INDICES WITHIN SAMPLE
*
*******************************************
egen ecoSTDhlth=std(healthcare)
egen ecoSTDtax=std(taxes)
gen ecoNSTD=(ecoSTDhlth+ecoSTDtax)/2
egen ecoSTD=std(ecoNSTD)

alpha ecoSTDhlth ecoSTDtax

egen socSTDabort=std(abortion)
egen socSTDcivil=std(civilunion)
gen socNSTD=(socSTDabort+socSTDcivil)/2
egen socSTD=std(socNSTD)

alpha socSTDabort socSTDcivil

*Reverse economic and social policy opinion scales so that positive values are more liberal
replace socSTD=socSTD*-1
replace ecoSTD=ecoSTD*-1
label var socSTD "Social Domain (M0 SD1, -conservative to +liberal)"
label var ecoSTD "Economic Domain (M0 SD1, -conservative to +liberal)"

*******************************************
*
* CORRELATIONS BETWEEN BIG FIVE MEASURES (NOT REPORTED)
*
*******************************************
foreach i in extraversion agreeable conscientiou neurotic openness{
corr BFI_`i' BF_`i'
}

*******************************************
*
* TEN FACETS AND POLITICAL OUTCOMES: TABLE 5 (COLUMNS 1-5)
*
*******************************************
reg b_ideol FACET_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
outreg FACET_* using "logs\Table05_facets.out", se bracket rdec(3) replace 
reg socSTD FACET_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
outreg FACET_* using "logs\Table05_facets.out", se bracket rdec(3) append 
reg ecoSTD FACET_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
outreg FACET_* using "logs\Table05_facets.out", se bracket rdec(3) append 
reg interest FACET_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
outreg FACET_* using "logs\Table05_facets.out", se bracket rdec(3) append 
logit repvote FACET_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [pweight=psweight] if insample==1, r
outreg FACET_* using "logs\Table05_facets.out", se bracket rdec(3) append

*******************************************
*
* TIPI V. BFI: TABLE 6 (COLUMNS 1-10)
*
*******************************************
reg b_ideol BF_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
outreg BF_extraversion BF_agreeable BF_conscientiou BF_neurotic BF_openness using "logs\Table06_comparison.out", se bracket rdec(3) replace 
reg b_ideol BFI_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
outreg BFI_* using "logs\Table06_comparison.out", se bracket rdec(3) append 

reg socSTD BF_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
outreg BF_* using "logs\Table06_comparison.out", se bracket rdec(3) append 
reg socSTD BFI_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
outreg BFI_* using "logs\Table06_comparison.out", se bracket rdec(3) append 

reg ecoSTD BF_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
outreg BF_* using "logs\Table06_comparison.out", se bracket rdec(3) append 
reg ecoSTD BFI_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
outreg BFI_* using "logs\Table06_comparison.out", se bracket rdec(3) append 

reg interest BF_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
outreg BF_* using "logs\Table06_comparison.out", se bracket rdec(3) append 
reg interest BFI_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
outreg BFI_* using "logs\Table06_comparison.out", se bracket rdec(3) append 

logit repvote BF_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [pweight=psweight] if insample==1, r
outreg BF_* using "logs\Table06_comparison.out", se bracket rdec(3) append 
logit repvote BFI_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [pweight=psweight] if insample==1, r
outreg BFI_* using "logs\Table06_comparison.out", se bracket rdec(3) append 

*******************************************
*
* SUPPLEMENTARY ANALYSIS (NOT REPORTED)
*
*******************************************
/*
reg b_ideol BFI_* FACET_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
test FACET_assertiveness FACET_activity FACET_altruism FACET_compliance FACET_order FACET_selfdiscipline FACET_anxiety FACET_depression FACET_aesthetics FACET_ideas 
reg socSTD BFI_* FACET_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
test FACET_assertiveness FACET_activity FACET_altruism FACET_compliance FACET_order FACET_selfdiscipline FACET_anxiety FACET_depression FACET_aesthetics FACET_ideas 
reg ecoSTD BFI_* FACET_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
test FACET_assertiveness FACET_activity FACET_altruism FACET_compliance FACET_order FACET_selfdiscipline FACET_anxiety FACET_depression FACET_aesthetics FACET_ideas 
*/
foreach i in b_ideol socSTD ecoSTD interest repvote{
pwcorr `i' FACET_* [aw=psweight], star(90)
}

*******************************************
*
* ANALYSIS OF VALIDATED TURNOUT, FIRST GENERATE OUTCOME MEAUSURE
*
*******************************************
*** DROP CASES POLIMETRIX DID NOT MATCH TO VOTER ROLLS
drop if vh_matched!=1

** Missing==> no turnout
recode vh_p2000 vh_g2000 vh_p2002 vh_g2002 vh_p2004 vh_g2004 vh_p2006 vh_g2006 (.=0)

**Generate Turnout in All Elections (2000-2006)
qui forvalues i=2000(2)2006{
 gen turn`i'=vh_g`i'
 replace turn`i'=0 if vh_g`i'!=1
}
gen turntotal=turn2000+turn2002+turn2004+turn2006
label var turntotal "All Elections"

**Restrict sample to individuals eligible to vote in 2000
replace insample=0 if age<26

**Restrict analysis to states where there is variation in turnout.
levelsof profile66, local(levels)
qui foreach state of local levels {
 summ turntotal if profile66==`state'
 replace insample=0 if r(sd)==0 & profile66==`state'
}

*Exclude MA because old voter file used (i.e., no turnout data for 2002-2006).
replace insample=0 if profile66==25

ologit turntotal BFI_* BF_* female r_black r_hispanic r_other age age2 state* if insample==1 [pw=psweight], r
replace insample=0 if e(sample)==0

*******************************************
*
* TEN FACETS AND POLITICAL OUTCOMES: TABLE 5 (COLUMN 6)
*
*******************************************
reg turntotal FACET_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
outreg FACET_* using "logs\Table05_facets.out", se bracket rdec(3) append 

*******************************************
*
* TIPI V. BFI: TABLE 6 (COLUMNS 11-12)
*
*******************************************
reg turntotal BF_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
outreg BF_* using "logs\Table06_comparison.out", se bracket rdec(3) append 
reg turntotal BFI_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight] if insample==1, r
outreg BFI_* using "logs\Table06_comparison.out", se bracket rdec(3) append 

pwcorr turntotal FACET_* [aw=psweight], star(90)

*******************************************
*
* CCES 2009 ANALYSIS: TABLES 3 & 4 (COLUMNS 2, 4, 6) 
*
*******************************************
include 02_Sub_Annual_Review_Analysis.do
