use "`localpath'sourcedata\cces_2009.dta", clear

*******************************************
*
* RECODE DEMOGRAPHIC VARIABLES
*
*******************************************
*Case Weight
gen weight=v200

* State, drop if missing state
drop if v259==0 | v259==.
quietly tab v259, gen(stateC_)
* drop State5 indicator--California (dominant category when weighted)
drop stateC_5

*Race
gen race=v211
tab race, gen(r_)
rename r_1 r_white
rename r_2 r_black
rename r_3 r_hispanic
gen r_other=r_4+r_5+r_6+r_7+r_8
label var r_white "White"
label var r_black "Black"
label var r_hispanic "Hispanic"
label var r_other "Other Race"

*Age
gen age=v288
gen age2=(age^2)/100
label var age "Age (in years)"
label var age2 "Age-squared/100"

*Female
recode v208 (1=0) (2=1) (*=.), gen(female)
label var female "Female=1"

***Education
*temporarily rename v213 to education for purposes of creating category indicators to get label
rename v213 education
qui tab education if education>=1 & education<=6, gen(educD_)
*median
drop educD_3
rename education v213

***Income
recode v246 (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (7=7) (8=8) (9=9) (10=10) (11=11) (12=12) (13=13) (14=14) (15=15) (*=.), gen(income)

replace income=(income-1)/14
label var income "Income (0=<$10k; .93=>150k; 1=RF)"
gen incomemis=(income==1)
label var incomemis "Income Missing/RF"

***Ideology
recode v261 (1=2) (2=1) (3 6=0) (4=-1) (5=-2) (*=.), gen(ideol)
label var ideol "Ideology (-2=V. Cons.; 2=V. Lib.; 0=Not. Sure/Mod.)"

* Economic policy opinions
recode cc09_56 (101/.=.), gen(taxspend)
egen ecoSTD=std(taxspend)
replace ecoSTD=ecoSTD*-1
label var ecoSTD "Economic Domain (M=0 SD=1, -conservative to +liberal)"

* Social policy opinions
recode cc09_53 (1=1) (2=2) (3=3) (4=4) (*=.), gen(abortion)
replace abortion=(abortion-1)/3
label var abortion "Pro Choice (0-1)"

recode cc09_54 (1=1) (2=0) (*=.), gen(gaymarriage)
replace gaymarriage=(gaymarriage-1)/3
label var gaymarriage "Support Gay Marriage, 1=Yes"

egen socSTDabort=std(abortion)
egen socSTDgmarr=std(gaymarriage)
gen socNSTD=(socSTDabort+socSTDgmarr)/2
egen socSTD=std(socNSTD)
label var socSTD "Social Domain (M0 SD1, -conservative to +liberal)"

alpha socSTDabort socSTDgmarr

*******************************************
*
* BIG FIVE/TIPI
*
*******************************************

*personality - extraverted
gen b_p_extraverted=cc09_07a
recode b_p_extraverted (8=.) (9=.)

*personality - critical 
gen b_p_critical=cc09_07b
recode b_p_critical (8=.) (9=.)

*personality - dependable
gen b_p_dependable=cc09_07c
recode b_p_dependable (8=.) (9=.)

*personality - anxious
gen b_p_anxious=cc09_07d
recode b_p_anxious (8=.) (9=.)

*personality - open to new experiences
gen b_p_open=cc09_07e
recode b_p_open (8=.) (9=.)

*personality - reserved
gen b_p_reserved=cc09_07f
recode b_p_reserved (8=.) (9=.)

*personality - sympathetic
gen b_p_sympathetic=cc09_07g
recode b_p_sympathetic (8=.) (9=.)

*personality - disorganized
gen b_p_disorganized=cc09_07h
recode b_p_disorganized (8=.) (9=.)

*personality - calm
gen b_p_calm=cc09_07i
recode b_p_calm (8=.) (9=.)

*personality - conventional
gen b_p_conventional=cc09_07j
recode b_p_conventional (8=.) (9=.)

*Items range from 0 to 1 -- higher values mean more of the trait

*Big Five - conscientiousness

recode b_p_disorganized (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(b_p_disorganized_R)
gen BF_conscientiousness = (((b_p_dependable + b_p_disorganized_R)/2)-1)/6
label var BF_conscientiousness "Conscientiousness (0-1)"

*Big Five - openness to experiences

recode b_p_conventional (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(b_p_conventional_R)
gen BF_openness = (((b_p_open + b_p_conventional_R)/2)-1)/6
label var BF_openness "Openness (0-1)"

*Big Five - agreeableness

recode b_p_critical (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(b_p_critical_R)
gen BF_agreeableness = (((b_p_sympathetic + b_p_critical_R)/2)-1)/6
label var BF_agreeableness "Agreeableness (0-1)"

*Big Five - emotional stability

recode b_p_anxious (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(b_p_anxious_R)
gen BF_stability = (((b_p_calm + b_p_anxious_R)/2)-1)/6
label var BF_stability "Emotional Stability (0-1)"

*Big Five - extraversion

recode b_p_reserved (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(b_p_reserved_R)
gen BF_extraversion = (((b_p_extraverted + b_p_reserved_R)/2)-1)/6
label var BF_extraversion "Extraversion (0-1)"

*******************************************
*
* INTERACTIONS: BIG FIVE WITH DEMOGRAPHICS
*
*******************************************
quietly foreach i in r_black r_hispanic r_other {
 gen BFcoX`i'=BF_conscientiousness*`i'
 label var BFcoX`i' "Conscientiousness x `i'"
 gen BFopX`i'=BF_openness*`i'
 label var BFopX`i' "Openness x `i'"
 gen BFagX`i'=BF_agreeableness*`i'
 label var BFagX`i' "Agreeableness x `i'"
 gen BFstX`i'=BF_stability*`i'
 label var BFstX`i' "Stability x `i'"
 gen BFexX`i'=BF_extraversion*`i'
 label var BFexX`i' "Extraversion x `i'"
}

*******************************************
*
* SET SAMPLE
*
*******************************************
*** First we'll set a constant sample and restrict to weighted cases

*All 13,800 cases have demographics

*Of these cases, 12,840 responded to all Big Five items
keep if BF_extra~=. & BF_agre~=. & BF_consci~=. & BF_open~=. & BF_stab~=.
count

* 10559 with ideology measures.
reg ideol socSTD ecoSTD
gen insample = e(sample)
keep if insample==1
count

set more 1
*******************************************
*
* TOBIT, AGGREGATE PERSONALITY EFFECTS: TABLE 3 (COLUMNS 2, 4, 6)
*
*******************************************

foreach i in ideol ecoSTD socSTD {

 quietly summ `i'
 local mini=r(min)+.01
 local maxi=r(max)-.01
 
 tobit `i' BF_* female r_black r_hispanic r_other age age2 educD_* income incomemis stateC_* [pweight=weight], cluster(v259) ll(`mini') ul(`maxi')
}

*******************************************
*
* TOBIT, PERSONALITY EFFECTS BY CONTEXT/RACE: TABLE 4 (COLUMNS 2, 4, 6)
*
*******************************************
**************************
*** Table 5, Tobit, Personality Effects by Context/Race
**************************

foreach i in ideol ecoSTD socSTD {

 quietly summ `i'
 local mini=r(min)+.01
 local maxi=r(max)-.01
 tobit `i' BF_* BF*r_* female r_black r_hispanic r_other age age2 educD_* income incomemis stateC_* [pweight=weight], cluster(v259)  ll(`mini') ul(`maxi')
}
